@startuml

' Core interface for the M2toM1 transformation component
interface M2toM1Transformer {
  -- Methods --
  + transformM2toM1(source: string): M1Code
  + validateM2Model(source: string): boolean
  __ overwritten Methods __
  + onDomReadyView(view: M2toM1View): void @UcpComponent
}

' Interface for parsing PlantUML
interface PlantUMLParser {
  -- Methods --
  + parse(source: string): M2Model
}

' Interface for validating models
interface ModelValidator {
  -- Methods --
  + validate(model: M2Model): boolean
}

' Interface for transforming models to code structure
interface ModelToCodeTransformer {
  -- Methods --
  + transform(model: M2Model): M1CodeStructure
  + setConfig(config: TransformerConfig): void
}

' Interface for generating final code
interface CodeGenerator {
  -- Methods --
  + generate(structure: M1CodeStructure, language: string): M1Code
}

' Orchestrator class that delegates tasks
class DefaultM2toM1Transformer {
  __ private Attributes __
    - _isProcessing: boolean
  -- Model Attributes --
    + sourceText: string
    + targetCode: M1Code
  __ Class Methods __
    + {static} static get dependencies(): [Array]
    + {static} static get weBeanUnitPaths(): [string]
    + constructor(): void
  __ Methods __
    + transformM2toM1(source: string): M1Code
    + validateM2Model(source: string): boolean
  __ overwritten Methods __
    + onUpdateView(view: M2toM1View, updateObject: Object): void @UcpComponent
    + onDomReadyView(view: M2toM1View): void @UcpComponent
  __ Properties --
    + get isProcessing(): boolean
    + set isProcessing(value: boolean): void
}

' Default implementation of parser
class DefaultPlantUMLParser {
  -- Model Attributes --
    + parsedModel: M2Model
  __ Methods __
    + parse(source: string): M2Model
}

' Default implementation of validator
class DefaultModelValidator {
  __ Methods __
    + validate(model: M2Model): boolean
}

' Default implementation of transformer
class DefaultModelToCodeTransformer {
  -- Model Attributes --
    + config: TransformerConfig
  __ Methods __
    + transform(model: M2Model): M1CodeStructure
    + setConfig(config: TransformerConfig): void
}

' Default implementation of code generator
class DefaultCodeGenerator {
  __ Methods __
    + generate(structure: M1CodeStructure, language: string): M1Code
}

' Configuration manager
class TransformerConfig {
  -- Model Attributes --
    + outputLanguage: string
    + targetPath: string
  __ Methods __
    + loadFromFile(file: string): void
}

' Representation of the parsed M2 model
class M2Model {
  -- Model Attributes --
    + classes: [ClassDescriptor]
    + relationships: [RelationshipDescriptor]
  __ Methods __
    + addClass(descriptor: ClassDescriptor): void
    + addRelationship(descriptor: RelationshipDescriptor): void
}

' Intermediate structure for M1 code
class M1CodeStructure {
  -- Model Attributes --
    + components: [ComponentDescriptor]
    + imports: [string]
  __ Methods __
    + addComponent(descriptor: ComponentDescriptor): void
}

' Final M1 code output
class M1Code {
  -- Model Attributes --
    + content: string
    + language: string
  __ Methods __
    + save(targetPath: string): void
}

' Abstract view interface for M2toM1
interface M2toM1View {
  -- Methods --
  + render(): void
  + updateStatus(status: string): void
  __ overwritten Methods __
  + onDomReady(view: M2toM1View): void @DefaultView
}

' Concrete view implementation
class DefaultM2toM1View {
  __ private Attributes __
    - _viewState: string
  -- Model Attributes --
    + sourceText: string
    + status: string
  __ Class Methods __
    + constructor(): void
  __ Methods __
    + render(): void
    + updateStatus(status: string): void
  __ overwritten Methods __
    + onDomReady(view: M2toM1View): void @DefaultView
}

' Relationships
DefaultM2toM1Transformer .up.|> M2toM1Transformer
DefaultM2toM1Transformer -down-> PlantUMLParser : delegates parsing
DefaultM2toM1Transformer -down-> ModelValidator : delegates validation
DefaultM2toM1Transformer -down-> ModelToCodeTransformer : delegates transformation
DefaultM2toM1Transformer -down-> CodeGenerator : delegates generation
DefaultM2toM1Transformer -down-> TransformerConfig : configured by
DefaultM2toM1Transformer -right-> M2toM1View : creates

DefaultPlantUMLParser .up.|> PlantUMLParser
DefaultModelValidator .up.|> ModelValidator
DefaultModelToCodeTransformer .up.|> ModelToCodeTransformer
DefaultCodeGenerator .up.|> CodeGenerator
DefaultM2toM1View .up.|> M2toM1View

PlantUMLParser -down-> M2Model : produces
ModelValidator -down-> M2Model : validates
ModelToCodeTransformer -down-> M2Model : uses
ModelToCodeTransformer -down-> M1CodeStructure : produces
CodeGenerator -down-> M1CodeStructure : uses
CodeGenerator -down-> M1Code : produces

' Show classes and members explicitly defined here
show M2toM1Transformer
show M2toM1Transformer members
show PlantUMLParser
show PlantUMLParser members
show ModelValidator
show ModelValidator members
show ModelToCodeTransformer
show ModelToCodeTransformer members
show CodeGenerator
show CodeGenerator members
show DefaultM2toM1Transformer
show DefaultM2toM1Transformer members
show DefaultPlantUMLParser
show DefaultPlantUMLParser members
show DefaultModelValidator
show DefaultModelValidator members
show DefaultModelToCodeTransformer
show DefaultModelToCodeTransformer members
show DefaultCodeGenerator
show DefaultCodeGenerator members
show TransformerConfig
show TransformerConfig members
show M2Model
show M2Model members
show M1CodeStructure
show M1CodeStructure members
show M1Code
show M1Code members
show M2toM1View
show M2toM1View members
show DefaultM2toM1View
show DefaultM2toM1View members

@enduml